@@ -54,8 +54,10 @@ typedef struct {
 static unsigned num_mons = 0;
 static mon_t* mons = NULL;
 
+static unsigned num_proc = 0;
+
 F_NONNULL F_NORETURN
-static void syserr_for_ev(const char* msg) { dmn_assert(msg); log_fatal("%s: %s", msg, dmn_logf_errno()); }
+static void syserr_for_ev(const char* msg) { log_fatal("%s: %s", msg, dmn_logf_errno()); }
 
 static int plugin_read_fd = -1;
 static int plugin_write_fd = -1;
@@ -146,6 +148,9 @@ static void mon_timeout_cb(struct ev_loop* loop, ev_timer* w, int revents V_UNUS
         sendq_enq(emc_encode_mon(this_mon->cmd->idx, true));
         ev_io_start(loop, plugin_write_watcher);
     }
+    if (num_proc > 0) {
+        num_proc--;
+    }
     this_mon->result_pending = false;
 }
 
@@ -166,7 +171,7 @@ static void mon_child_cb(struct ev_loop* loop, ev_child* w, int revents V_UNUSED
     }
     else {
         if(WIFSIGNALED(status))
-            dmn_log_warn("Monitor child process for '%s' terminated by signal %u", this_mon->cmd->desc, WTERMSIG(status));
+            dmn_log_warn("Monitor child process for '%s' terminated by signal %i", this_mon->cmd->desc, WTERMSIG(status));
         else
             dmn_log_warn("Monitor child process for '%s' terminated abnormally...", this_mon->cmd->desc);
     }
@@ -178,6 +183,9 @@ static void mon_child_cb(struct ev_loop* loop, ev_child* w, int revents V_UNUSED
             sendq_enq(emc_encode_mon(this_mon->cmd->idx, failed));
             ev_io_start(loop, plugin_write_watcher);
         }
+        if (num_proc > 0) {
+            num_proc--;
+        }
         this_mon->result_pending = false;
     }
 }
@@ -188,6 +196,16 @@ static void mon_interval_cb(struct ev_loop* loop, ev_timer* w, int revents V_UNU
     mon_t* this_mon = w->data;
     dmn_assert(!this_mon->result_pending);
 
+    if (this_mon->cmd->max_proc > 0 && num_proc >= this_mon->cmd->max_proc) {
+        // If more than max_proc processes are running, reschedule excess
+        //   checks to run 0.1 seconds later. After a few passes, this will
+        //   smooth the schedule out to prevent a thundering herd.
+        ev_timer_stop(loop, this_mon->interval_timer);
+        ev_timer_set(this_mon->interval_timer, 0.1, this_mon->cmd->interval);
+        ev_timer_start(loop, this_mon->interval_timer);
+        return;
+    }
+
     // Before forking, block all signals and save the old mask
     //   to avoid a race condition where local sighandlers execute
     //   in the child between fork and exec().
@@ -225,6 +243,7 @@ static void mon_interval_cb(struct ev_loop* loop, ev_timer* w, int revents V_UNU
         execv(this_mon->cmd->args[0], this_mon->cmd->args);
         log_fatal("execv(%s, ...) failed: %s", this_mon->cmd->args[0], dmn_logf_strerror(errno));
     }
+    num_proc++;
 
     // restore previous signal mask from before fork in parent
     if(pthread_sigmask(SIG_SETMASK, &saved_mask, NULL))
@@ -246,7 +265,7 @@ static void plugin_write_cb(struct ev_loop* loop, ev_io* w, int revents V_UNUSED
         ssize_t write_rv = write(plugin_write_fd, &data, 4);
         if(write_rv != 4) {
             if(write_rv < 0) {
-                if(errno == EAGAIN || errno == EWOULDBLOCK)
+                if(ERRNO_WOULDBLOCK)
                     return; // pipe full, wait for more libev notification of write-ready
                 else if(errno == EINTR)
                     continue; // try this write again immediately
@@ -275,8 +294,6 @@ static void plugin_write_cb(struct ev_loop* loop, ev_io* w, int revents V_UNUSED
 
 F_NONNULL
 static void die_gracefully(struct ev_loop* loop) {
-    dmn_assert(loop);
-
     dmn_assert(killed_by);
     static bool done_once = false;
     if(!done_once) { // avoid repetition
@@ -302,7 +319,7 @@ static void die_gracefully(struct ev_loop* loop) {
 
 F_NONNULL
 static void sig_cb(struct ev_loop* loop, ev_signal* w, int revents V_UNUSED) {
-    dmn_assert(loop); dmn_assert(w); dmn_assert(revents == EV_SIGNAL);
+    dmn_assert(revents == EV_SIGNAL);
     switch(w->signum) {
         case SIGINT:
         case SIGTERM:
